@@ -17,11 +17,11 @@ SVN::Hooks - A framework for implementing Subversion hooks.
 
 =head1 VERSION
 
-Version 0.90
+Version 0.91
 
 =cut
 
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 
 our @Conf_Files = ('conf/svn-hooks.conf');
 our $Repo       = undef;
@@ -38,6 +38,7 @@ sub run_hook {
 
     # Reload all configuration files
     foreach my $conf (@Conf_Files) {
+	next unless -e "$Repo/$conf"; # Configuration files are optional
 	package main;
 	unless (my $return = do "$Repo/$conf") {
 	    die "couldn't parse '$Repo/$conf': $@\n" if $@;
@@ -147,14 +148,14 @@ A single script can implement several hooks:
 	use SVN::Hooks;
 
 	START_COMMIT {
-	my ($repo_path, $username, $capabilities) = @_;
+	    my ($repo_path, $username, $capabilities) = @_;
 	    # ...
-	}
+	};
 
 	PRE_COMMIT {
 	    my ($svnlook) = @_;
 	    # ...
-	}
+	};
 
 	run_hook($0, @ARGV);
 
@@ -193,7 +194,7 @@ repository to a new revision.
 
 A hook is a specifically named program that is called by the
 Subversion server during the execution of some operations. There are
-exactly nine hooks which must reside under the C<conf> directory in
+exactly nine hooks which must reside under the C<hooks> directory in
 the repository. When you create a new repository, you get nine
 template files in this directory, all of them having the C<.tmpl>
 suffix and helpful instructions inside explaining how to convert them
