@@ -339,7 +339,7 @@ sub _functor {
 	close $th;
 
 	local $ENV{SVNREPOPATH} = $repo_path;
-	if (system("$cmd $temp/file 1>$temp/output 2>$temp/error") == 0) {
+	if (system("$cmd $temp/file $path 1>$temp/output 2>$temp/error") == 0) {
 	    return `cat $temp/output`;
 	}
 	else {
